@@ -16,23 +16,28 @@ Implementation Notes
 
 **Hardware:**
 
-* 1.8" SPI TFT display, 160x128 18-bit color:
-  https://www.adafruit.com/product/618
-* Adafruit 0.96" 160x80 Color TFT Display w/ MicroSD Card Breakout:
-  https://www.adafruit.com/product/3533
-* 1.8" Color TFT LCD display with MicroSD Card Breakout:
-  https://www.adafruit.com/product/358
-* Adafruit 1.44" Color TFT LCD Display with MicroSD Card breakout:
-  https://www.adafruit.com/product/2088
-* Adafruit Mini Color TFT with Joystick FeatherWing:
-  https://www.adafruit.com/product/3321
+* `1.8" SPI TFT display, 160x128 18-bit color
+  <https://www.adafruit.com/product/618>`_ (Product ID: 618)
+* `Adafruit 0.96" 160x80 Color TFT Display w/ MicroSD Card Breakout
+  <https://www.adafruit.com/product/3533>`_ (Product ID: 3533)
+* `1.8" Color TFT LCD display with MicroSD Card Breakout:
+  <https://www.adafruit.com/product/358>`_ (Product ID: 358)
+* `Adafruit 1.44" Color TFT LCD Display with MicroSD Card breakout:
+  <https://www.adafruit.com/product/2088>`_ (Product ID: 2088)
+* `Adafruit Mini Color TFT with Joystick FeatherWing:
+  <https://www.adafruit.com/product/3321>`_ (Product ID: 3321)
 
 **Software and Dependencies:**
 
 * Adafruit CircuitPython firmware for the supported boards:
-  https://github.com/adafruit/circuitpython/releases
+  https://circuitpython.org/downloads
 
 """
+try:
+    # used for typing only
+    from typing import Any
+except ImportError:
+    pass
 
 import displayio
 
@@ -63,19 +68,35 @@ _INIT_SEQUENCE = bytearray(
     b"\x29\x80\x64"  # _DISPON
 )
 
+
 # pylint: disable=too-few-public-methods
 class ST7735R(displayio.Display):
-    """ST7735 driver for ST7735R"""
+    """
+    ST7735R display driver
+
+    :param displayio.FourWire bus: bus that the display is connected to
+    :param bool bgr: (Optional) An extra init sequence to append (default=False)
+    :param bool invert: (Optional) Invert the colors (default=False)
+    """
+
+    def __init__(
+        self,
+        bus: displayio.FourWire,
+        *,
+        bgr: bool = False,
+        invert: bool = False,
+        **kwargs: Any
+    ):
 
-    def __init__(self, bus, *, bgr=False, invert=False, **kwargs):
-        """
-        :param bool bgr: (Optional) An extra init sequence to append (default=False)
-        """
         init_sequence = _INIT_SEQUENCE
         if bgr:
             init_sequence += (
                 b"\x36\x01\xC0"  # _MADCTL Default rotation plus BGR encoding
             )
+        else:
+            init_sequence += (
+                b"\x36\x01\xC8"  # _MADCTL Default rotation plus RGB encoding
+            )
         if invert:
             init_sequence += b"\x21\x00"  # _INVON
         super().__init__(bus, init_sequence, **kwargs)
