@@ -1,3 +1,6 @@
+# SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
+# SPDX-License-Identifier: MIT
+
 """
 This test will initialize the display using displayio and draw a solid green
 background, a smaller purple rectangle, and some yellow text.
@@ -23,7 +26,7 @@ display_bus = displayio.FourWire(
 display = ST7735R(display_bus, width=160, height=128, rotation=90, bgr=True)
 
 # Make the display context
-splash = displayio.Group(max_size=10)
+splash = displayio.Group()
 display.show(splash)
 
 color_bitmap = displayio.Bitmap(160, 128, 1)
@@ -41,7 +44,7 @@ inner_sprite = displayio.TileGrid(inner_bitmap, pixel_shader=inner_palette, x=5,
 splash.append(inner_sprite)
 
 # Draw a label
-text_group = displayio.Group(max_size=10, scale=2, x=11, y=64)
+text_group = displayio.Group(scale=2, x=11, y=64)
 text = "Hello World!"
 text_area = label.Label(terminalio.FONT, text=text, color=0xFFFF00)
 text_group.append(text_area)  # Subgroup for text scaling
